{%extends "parent.html"%}

{%block title%}
Static Resource List
{%endblock%}

{%block content%}
    {%set subTitle='Resource'%}
    {%set current='Resource'%}
    {%include "header.html"%}

    <div class="menu h-fil fl bg">
        <a href="javascript:;" class="block" data-menu="css" style='color:#333;background-color: #f5f5f5'>CSS &gt;&gt;</a>
        <a href="javascript:;" class="block" data-menu="js">JS &gt;&gt;</a>
        <a href="javascript:;" class="block" data-menu="image">IMAGE &gt;&gt;</a>
    </div>
    <div class="canvas ">
        <div class="section" id="section-css"> <ul class="tlist">
                            {% for tpl in css %}
                            <li>
                                <a class="title t-ell" target="_blank" href="/{{css_dir}}/{{tpl}}">{{tpl}}</a>
                            </li>
                            {% endfor %}
                        </ul></div>
        <div class="section" id="section-js" style="display:none"><ul class="tlist">
                            {% for tpl in js %}
                            <li>
                                <a class="title t-ell" target="_blank" href="/{{js_dir}}/{{tpl}}">{{tpl}}</a>
                            </li>
                            {% endfor %}
                        </ul></div>
        <div class="section" id="section-image" style="display:none"> <ul class="tlist">
                            {% for tpl in img %}
                            <li>
                                <a class="title t-ell" target="_blank" href="/{{img_dir}}/{{tpl}}">{{tpl}}</a>
                            </li>
                            {% endfor %}
                        </ul></div>
                    </div>
{%endblock%}