{%extends "parent.html"%}

{%block title%}
Tempalte List
{%endblock%}

{%block content%}
    {%set subTitle='Templates'%}
    {%set current='Templates'%}
    {%include "header.html"%}
        <div class="menu h-fil fl bg">
            <a href="javascript:;" class="block" data-menu="main" style='color:#333;background-color: #f5f5f5'>MAIN &gt;&gt;</a>
            <a href="javascript:;" class="block" data-menu="module">MODULE &gt;&gt;</a>
            <a href="javascript:;" class="block" data-menu="common">COMMON &gt;&gt;</a>
        </div>

    <div class="canvas">
       {{content}}
        </div>

{%endblock%}