{%extends "parent.html"%}

{%block title%}
Tempalte Data Manager
{%endblock%}

{%block content%}
        <div class="wrapper">
            
            <h1>Data Manager for Tpl => {{name}}</h1>
            <form method="post" id="ursa" action="/data.so">
                <p class="desc">
                    Paste or type json data in the textarea below.
                    <button id="submit" type="submit">Submit</button>

                </p>
                <input type="hidden" name="tpl" value="{{name}}" />
                <textarea name="data" id="data" >{{data}}</textarea>
            </form>
        </div>
{%endblock%}