{%extends "parent.html"%}

{%block title%}
Tempalte List
{%endblock%}

{%block content%}
    {%set subTitle='Templates'%}
    {%set current='Templates'%}
    {%include "header.html"%}
        <div class="menu h-fil fl bg">
            <a href="javascript:;" class="block" data-menu="main" style='color:#333;background-color: #f5f5f5'>MAIN &gt;&gt;</a>
            <a href="javascript:;" class="block" data-menu="module">MODULE &gt;&gt;</a>
            <a href="javascript:;" class="block" data-menu="common">COMMON &gt;&gt;</a>
        </div>

    <div class="canvas">
        <div class="section" id="section-main"> 
             <ul class="tlist">
                            {% for tpl in tpls %}
                            <li>
                                <a class="title" href="{{tpl}}.ut">{{tpl}}.tpl</a>
                                <a class="mgr" href="{{tpl}}.m">mgr</a>
                                <a class="mgr" href="{{tpl}}.data">data</a>
                            </li>
                            {% endfor %}
                        </ul></div>
        <div class="section" id="section-module" style="display:none">
              <ul class="tlist">
                            {% for tpl in module_tpls %}
                            <li>
                                <a class="title" href="{{tpl}}.ut">{{tpl}}.tpl</a>
                                <a class="mgr" href="{{tpl}}.m">mgr</a>
                                <a class="mgr" href="{{tpl}}.data">data</a>
                            </li>
                            {% endfor %}
                </ul></div>
        <div class="section" id="section-common" style="display:none">
            <ul class="tlist">
                            {% for tpl in common_tpls %}
                            <li>
                                <a class="title" href="{{tpl}}.ut">{{tpl}}.tpl</a>
                                <a class="mgr" href="{{tpl}}.m">mgr</a>
                                <a class="mgr" href="{{tpl}}.data">data</a>
                            </li>
                            {% endfor %}
            </ul></div>
        </div>

{%endblock%}