<div class="header w-fil">
	<div class="fl bo h-fil logo">Ursa/<span class="p18">{{subTitle}}</span></div>
	<ul class="p24 fl h-fil">
		{%set links=[['/','Templates'],['/s','Resource'],['/h','Help']]%}

		{%for k in links%}
		<li class="fl bo"><a href="{{k[0]}}" class="block{%if current==k[1]%} on{%endif%}">{{k[1]}}</a></li>
		{%endfor%}
	</ul>
</div>